@@ -113,7 +113,7 @@ class Electrode:
         potential: float or np.array
             Potential computed at the indicated point (float) or points (np.array)
         '''
-        if not isinstance(self.sigma, (float, int, np.float, np.integer)):
+        if not isinstance(self.sigma, (float, int, np.integer)):
             assert len(np.array(self.sigma)) == 3,  "Extracellular potentials can be computed for isotropic " \
                                                     "(scalar sigma) or anisotropic (3-D sigma) medium"
 
@@ -130,7 +130,7 @@ class Electrode:
         if np.array(points).ndim == 1:
             points = np.array([points])
 
-        if isinstance(self.current, (float, int, np.float, np.integer)):
+        if isinstance(self.current, (float, int, np.integer)):
             if self.current != 0:
                 if recompute_mapping:
                     self.compute_mapping(points, npoints, model=model, seed=seed)
@@ -178,7 +178,7 @@ class Electrode:
         self.points = points
 
         mapping = np.zeros(len(points))
-        if not isinstance(self.sigma, (float, int, np.float, np.integer)):
+        if not isinstance(self.sigma, (float, int, np.integer)):
             assert len(np.array(self.sigma)) == 3, "Extracellular potentials can be computed for isotropic " \
                                                    "(scalar sigma) or anisotropic (3-D sigma) medium"
         if self.npoints == 1:
@@ -188,7 +188,7 @@ class Electrode:
             assert self.main_axes is not None, "For 'npoints' > 1 the electrode main_axes must be set"
             stim_points = self.get_n_points(npoints)
             split_current = 1. / self.npoints
-        if isinstance(self.sigma, (float, int, np.float, np.integer)):
+        if isinstance(self.sigma, (float, int, np.integer)):
             # Isotropic
             # for i_p, pos in enumerate(points):
             for i_e, el_pos in enumerate(stim_points):
@@ -247,7 +247,7 @@ class Electrode:
         Parameters
         ----------
         mapping: np.array
-            Mapping 
+            Mapping
         points: np.array
             3D points to compute mapping
         """
@@ -302,6 +302,32 @@ class Electrode:
 
         return points
 
+    def are_points_inside(self, points):
+        points = np.array(points)
+        if points.ndim == 1:
+            points = [points]
+
+        is_inside_array = np.zeros(len(points), dtype=bool)
+
+        for i, point in enumerate(points):
+            # check if in the same plane
+            is_inside = False
+            if not np.isclose(np.dot(self.normal, point - self.position), 0, atol=1):
+                is_inside = False
+            else:
+                if self.shape == 'square':
+                    if np.abs(np.dot(point - self.position, self.main_axes[0])) < self.size and \
+                            np.abs(np.dot(point - self.position, self.main_axes[1])) < self.size:
+                        is_inside = True
+                elif self.shape == 'rect':
+                    if np.abs(np.dot(point - self.position, self.main_axes[0])) < self.size[0] and \
+                            np.abs(np.dot(point - self.position, self.main_axes[1])) < self.size[1]:
+                        is_inside = True
+                elif self.shape == 'circle':
+                    if np.linalg.norm(point - self.position) < self.size:
+                        is_inside = True
+            is_inside_array[i] = is_inside
+        return np.squeeze(is_inside_array)
 
 
 class MEA(object):
@@ -362,6 +388,11 @@ class MEA(object):
         else:
             self.model = 'semi'
 
+        if 'pitch' in info.keys():
+            self.pitch = info['pitch']
+        else:
+            self.pitch = None
+
         if self.plane == 'xy':
             self.main_axes = np.array([[1, 0, 0], [0, 1, 0]])
         elif self.plane == 'yz':
@@ -375,7 +406,7 @@ class MEA(object):
                 if np.dot(positions[0], positions[1]) != np.linalg.norm(positions[0] * positions[1]):
                     normal = np.cross(positions[0], positions[1])
                     if np.linalg.norm(normal) > 0:
-                        normal /= np.linalg.norm(normal)
+                        normal = normal / np.linalg.norm(normal)
                         self.normal = np.array([normal] * self.number_electrodes)
                     else:
                         self.normal = [None] * self.number_electrodes
@@ -470,6 +501,26 @@ class MEA(object):
                 currents[i] = el.current
         return currents
 
+    def get_closest_electrode_idx(self, pos):
+        '''
+        Returns index of electrode closest to the specified 3D point.
+
+        Parameters
+        ----------
+        pos: list or np.array
+            Array of 3d position
+
+        Returns
+        -------
+        index: int
+            The index of the closest electrode
+        '''
+        dists = np.zeros(self.number_electrodes)
+        for i, el in enumerate(self.electrodes):
+            dists[i] = np.linalg.norm(pos - el.position)
+
+        return np.argmin(dists)
+
     def _get_electrode_positions(self):
         pos = np.zeros((self.number_electrodes, 3))
         for i, el in enumerate(self.electrodes):
@@ -539,7 +590,7 @@ class MEA(object):
         current_value: float or array
             Current value for the specified electrode
         '''
-        if isinstance(current_value, (float, int, np.float, np.integer)):
+        if isinstance(current_value, (float, int, np.integer)):
             if self.currents.ndim == 1:
                 self.electrodes[el_id].current = current_value
             else:
@@ -550,7 +601,7 @@ class MEA(object):
                 if el_i == el_id:
                     el.current = current_value
                 else:
-                    if isinstance(el.current, (float, int, np.float, np.integer)):
+                    if isinstance(el.current, (float, int, np.integer)):
                         el.current = np.array([el.current] * len(current_value))
                     elif isinstance(el.current, (list, np.ndarray)):
                         if len(el.current) != len(current_value):
@@ -713,7 +764,7 @@ class MEA(object):
                 print("Error: expected 3d point")
                 return
             else:
-                if isinstance(c, (float, int, np.float, np.integer)):
+                if isinstance(c, (float, int, np.integer)):
                     vp = 0
                 else:  # isinstance(c, (list, np.ndarray)):
                     vp = np.zeros(len(c))
@@ -730,7 +781,7 @@ class MEA(object):
                 print("Error: expected 3d points")
                 return
             else:
-                if isinstance(c, (float, int, np.float, np.integer)):
+                if isinstance(c, (float, int, np.integer)):
                     vp = np.zeros(points.shape[0])
                 else:  # isinstance(c, (list, np.ndarray)):
                     vp = np.zeros((points.shape[0], len(c)))
@@ -1111,7 +1162,7 @@ def get_positions(elinfo, center=True):
 
             if isinstance(dim, (int, np.integer)):
                 dim = [dim, dim]
-            if isinstance(pitch, (int, np.integer)) or isinstance(pitch, (float, np.float)):
+            if isinstance(pitch, (int, np.integer)) or isinstance(pitch, float):
                 pitch = [pitch, pitch]
             if len(dim) == 2:
                 d1 = np.array([])
@@ -1122,7 +1173,7 @@ def get_positions(elinfo, center=True):
                     stagger = None
                 for d_i in np.arange(dim[1]):
                     if stagger is not None:
-                        if isinstance(stagger, (int, np.integer)) or isinstance(stagger, (float, np.float)):
+                        if isinstance(stagger, (int, np.integer)) or isinstance(stagger, float):
                             if np.mod(d_i, 2):
                                 d1new = np.arange(dim[0]) * pitch[0] + stagger
                             else:
@@ -1158,7 +1209,7 @@ def get_positions(elinfo, center=True):
                     stagger = None
                 for d_i, d in enumerate(dim):
                     if stagger is not None:
-                        if isinstance(stagger, (int, np.integer)) or isinstance(stagger, (float, np.float)):
+                        if isinstance(stagger, (int, np.integer)) or isinstance(stagger, float):
                             if np.mod(d_i, 2):
                                 d1new = np.arange(d) * pitch[0] + stagger
                             else:
